nzmetservice - A Python package for handling  New Zealand MetService forecast data
==================================================================================

The nzmetservice package contains various functions for downloading, processing, and handling of New Zealand MetService forecast data.
This package is not associated with the MetService.

.. Documentation
.. --------------
.. The primary documentation for the package can be found `here <http://eto.readthedocs.io>`_.

Installation
------------
nzmetservice can be installed via pip or conda::

  pip install nzmetservice

or::

  conda install -c mullenkamp nzmetservice

The core dependencies are `Pandas <http://pandas.pydata.org/pandas-docs/stable/>`_ and `xarray <http://xarray.pydata.org>`_.
